@@ -33,6 +33,7 @@ namespace Oxygen
 
         //! constructor
         WidgetSizeData( void ):
+            _widget(NULL),
             _width(-1),
             _height(-1),
             _alpha(false)
@@ -43,31 +44,21 @@ namespace Oxygen
         {}
 
         //! setup connections
-        void connect( GtkWidget* ) const
-        {}
+        void connect( GtkWidget* widget )
+        {
+            _widget=widget;
+        }
 
         //! disconnect
         void disconnect( GtkWidget* ) const
         {}
 
-        //! update size, returns true if changed
-        virtual bool updateSize( int width, int height )
-        {
-            if( width == _width && height == _height ) return false;
-            _width = width;
-            _height = height;
-            return true;
-        }
-
-        //! update alpha channel presence
-        void setAlpha( bool isAlpha )
-        { _alpha=isAlpha; }
-
-        //! determine if the widget had alpha channel on latest update
-        bool wasAlpha()
-        { return _alpha; }
+        //! update XShape, return true if size has changed
+        bool updateXShape();
 
         private:
+        //! target widget
+        GtkWidget* _widget;
 
         //! old width
         int _width;
