@@ -30,9 +30,12 @@
 
 #include <iostream>
 #include <cairo/cairo.h>
+
+#ifdef GDK_WINDOWING_X11
 #include <cairo/cairo-xlib.h>
 #include <gdk/gdkx.h>
 #include <X11/Xatom.h>
+#endif
 
 namespace Oxygen
 {
@@ -40,9 +43,13 @@ namespace Oxygen
     //______________________________________________
     ShadowHelper::ShadowHelper( void ):
         _size(0),
-        _atom(0),
         _hooksInitialized( false )
     {
+
+        #ifdef GDK_WINDOWING_X11
+        _atom = None;
+        #endif
+
         #if OXYGEN_DEBUG
         std::cerr << "Oxygen::ShadowHelper::ShadowHelper" << std::endl;
         #endif
@@ -68,6 +75,7 @@ namespace Oxygen
         std::cerr << "Oxygen::ShadowHelper::reset" << std::endl;
         #endif
 
+        #ifdef GDK_WINDOWING_X11
         GdkScreen* screen = gdk_screen_get_default();
         if( !screen ) return;
 
@@ -76,11 +84,14 @@ namespace Oxygen
         // round pixmaps
         for( PixmapList::const_iterator iter = _roundPixmaps.begin(); iter != _roundPixmaps.end(); ++iter )
         { XFreePixmap(display, *iter); }
-        _roundPixmaps.clear();
 
         // square pixmaps
         for( PixmapList::const_iterator iter = _squarePixmaps.begin(); iter != _squarePixmaps.end(); ++iter )
         { XFreePixmap(display, *iter); }
+        #endif
+
+        // clear arrays
+        _roundPixmaps.clear();
         _squarePixmaps.clear();
 
         // reset size
@@ -217,6 +228,7 @@ namespace Oxygen
         std::cerr << "Oxygen::ShadowHelper::createPixmapHandles" << std::endl;
         #endif
 
+        #ifdef GDK_WINDOWING_X11
         // create atom
         if( !_atom )
         {
@@ -300,14 +312,18 @@ namespace Oxygen
 
         }
 
+        #endif
+
     }
 
     //______________________________________________
+    #ifdef GDK_WINDOWING_X11
     Pixmap ShadowHelper::createPixmap( const Cairo::Surface& surface, int opacity ) const
     {
         assert( surface.isValid() );
-        const int width( cairo_surface_get_width( surface ) );
-        const int height( cairo_surface_get_height( surface ) );
+        int width(0);
+        int height(0);
+        cairo_surface_get_size( surface, width, height );
 
         GdkScreen* screen = gdk_screen_get_default();
         Display* display( GDK_DISPLAY_XDISPLAY( gdk_screen_get_display( screen ) ) );
@@ -339,11 +355,14 @@ namespace Oxygen
         return pixmap;
 
     }
+    #endif
 
     //______________________________________________
     void ShadowHelper::installX11Shadows( GtkWidget* widget )
     {
 
+        #ifdef GDK_WINDOWING_X11
+
         #if OXYGEN_DEBUG
         std::cerr
             << "Oxygen::ShadowHelper::installX11Shadows - "
@@ -405,6 +424,8 @@ namespace Oxygen
             GDK_DISPLAY_XDISPLAY( display ), GDK_WINDOW_XID(window), _atom, XA_CARDINAL, 32, PropModeReplace,
             reinterpret_cast<const unsigned char *>(&data[0]), data.size() );
 
+        #endif
+
     }
 
     //_______________________________________________________
@@ -413,9 +434,11 @@ namespace Oxygen
 
         if( !GTK_IS_WIDGET( widget ) ) return;
 
+        #ifdef GDK_WINDOWING_X11
         GdkWindow  *window = gtk_widget_get_window( widget );
         GdkDisplay *display = gtk_widget_get_display( widget );
         XDeleteProperty( GDK_DISPLAY_XDISPLAY( display ), GDK_WINDOW_XID(window), _atom);
+        #endif
 
     }
 
